/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.webidor;

import java.util.Date;
import java.util.UUID;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlRootElement;

/** Basic identification of a game.
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class GameId {
    @XmlAttribute
    private String white;
    @XmlAttribute
    private String black;
    @XmlAttribute
    private long started;
    @XmlAttribute
    private long modified;
    @XmlAttribute
    private GameStatus status;
    @XmlID @XmlAttribute
    private String id;

    GameId() {
    }

    public GameId(String first, String second) {
        this(first, second, new Date());
    }
    private GameId(String first, String second, Date d) {
        this(
            UUID.randomUUID().toString(),
            first, second, d, d, GameStatus.whiteMove
        );
    }

    public GameId(String id, String first, String second, Date started, Date last, GameStatus result) {
        this.white = first;
        this.black = second;
        this.id = id;
        this.started = started.getTime();
        this.modified = last.getTime();
        this.status = result;
    }

    public String getId() {
        return id;
    }

    public String getWhite() {
        return white;
    }

    public String getBlack() {
        return black;
    }

    public long getStarted() {
        return started;
    }

    public long getModified() {
        return modified;
    }

    public GameStatus getStatus() {
        return status;
    }
}
